Chromium Code Reviews

Unified Diff: views/event.h

Issue 3361003: Revert 58215 - Revert 58186 - Move the keyboard files from base/ to app/.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 10 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
« no previous file with comments | « views/controls/tree/tree_view.cc ('k') | views/event.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: views/event.h
===================================================================
--- views/event.h (revision 58386)
+++ views/event.h (working copy)
@@ -6,8 +6,8 @@
#define VIEWS_EVENT_H_
#pragma once
+#include "app/keyboard_codes.h"
#include "base/basictypes.h"
-#include "base/keyboard_codes.h"
#include "gfx/point.h"
#if defined(OS_LINUX)
@@ -309,7 +309,7 @@
public:
// Create a new key event
KeyEvent(EventType type,
- base::KeyboardCode key_code,
+ app::KeyboardCode key_code,
int event_flags,
int repeat_count,
int message_flags);
@@ -317,11 +317,11 @@
explicit KeyEvent(GdkEventKey* event);
#endif
// This returns a VKEY_ value as defined in base/keyboard_codes.h which is
// the Windows value.
// On GTK, you can use the methods in keyboard_code_conversion_gtk.cc to
// convert this value back to a GDK value if needed.
- base::KeyboardCode GetKeyCode() const {
+ app::KeyboardCode GetKeyCode() const {
return key_code_;
}
@@ -340,7 +340,7 @@
private:
- base::KeyboardCode key_code_;
+ app::KeyboardCode key_code_;
int repeat_count_;
int message_flags_;
« no previous file with comments | « views/controls/tree/tree_view.cc ('k') | views/event.cc » ('j') | no next file with comments »
@@ -317,11 +317,11 @@
explicit KeyEvent(GdkEventKey* event);
#endif
- // This returns a VKEY_ value as defined in base/keyboard_codes.h which is
+ // This returns a VKEY_ value as defined in app/keyboard_codes.h which is
// the Windows value.
// On GTK, you can use the methods in keyboard_code_conversion_gtk.cc to

Powered by Google App Engine